% This is the ODE to be solved for the in-trap dynamics of a BEC with any
% initial state
% equations as in Yi and You PRA 67,045601, eq(3)&(4) retaining the trap
% term

function dxdt=feqntrapdynamic(t,x)
% x(1) is qr, x(2) is qrd, x(3) is qz, x(4) is qzd

global ASN;
global FLG;
global NUM;
global FRA;
global FRP;

global MAS;
global MAG;

ab=0.53e-10;
mub=9.274e-24;
mu0=4*pi*1e-7;
hbar=1.05e-34;

%Li-7 (1,1) state HF 
ma=MAS*1.67e-27;
%%%%

%%exp parameters
N=NUM;
fa=FRA;
fp=FRP;
wa=fa*2*pi;
wp=fp*2*pi;

%ASN is s-wave scattering length in Bohr Radii
as=ASN*ab;
g2=mu0*(MAG*mub)^2/(4*pi);

ap=sqrt(hbar/(ma*wp));
lam=wa/wp; % the trap aspect ratio

%%original code. 
p0=sqrt(2/pi)*N*as/ap;
p2=FLG*sqrt(2/pi)*N*g2/(3*hbar*wp*ap^3);
%%end original code. %%


% if fuse You values 
%lam=2;
%p0=10;
%p2=10;

k=x(1)/x(3);

sk=sqrt(1-k^2);
hk=atanh(sk)/sk;
ak=(k^2-1)^2;
fk=0.5*(-4*k^4-7*k^2+2+9*k^4*hk)/ak;
gk=(-2*k^4+10*k^2+1-9*k^2*hk)/ak;

%a=x(1)'=x(2)
a=x(2);
%b=x(2)'=qr''
b=1/x(1)^3-(p2*fk-p0)/(x(1)^3*x(3))-x(1);
%c=x(3)'=qz'=x(4)
c=x(4);
%d=x(4)'=qz''
d=1/x(3)^3-(p2*gk-p0)/(x(1)^2*x(3)^2)-lam^2*x(3);

dxdt=[a;b;c;d];

