function [Asp,tWithMDDI,Asp0,tNoMDDI,y,y0] = fintrapevolve(endtime, guessSize, asnForEquilibStart,changeRadialAxial)
%{
fintrapevolve:  solves in-trap aspect ratio as a function of time. Used for in-trap dynamics.

INPUTS
endtime = time in ms to end simulation
guessSize = 2 element array guess at the [radial, axial] size used in 
            solving equilibrium size. Make sure decimal input.
asnForEquilibStart = used when starting for a stable condensate and shifting ASN to collapse BEC.
changeRadialAxial = change (multiplicative) to equilibrium trap size.

OUTPUTS
Asp = Aspect ratio calculated with MDDI effects
tWithMDDI  = 1D array of timesteps corresponding to Asp
Asp0 = Aspect ratio (for each ixx) calculated without MDDI effects
tNoMDDI = 1D array of timesteps corresponding to Asp0
%}
global ASN FLG NUM FRA FRP MAS MAG;
timeDivisions=20*1000; %originally 1000

endtau=ceil(endtime/timeDivisions*2*pi*FRP); % in tau (t*omega_p)

FLG=1;
    asnBackUp = ASN; %this is for when starting for a stable condensate and shifting ASN to collapse BEC.
    ASN = asnForEquilibStart;
[x, fval]=fsolve(@feqntrap,guessSize,optimset('Display','final'));
    ASN=asnBackUp;
%change size of BEC
xx(1)=x(1)*changeRadialAxial(1);
xx(2)=x(2)*changeRadialAxial(2);
[tau,y]=ode113(@feqntrapdynamic,[0 endtau], [xx(1);0;xx(2);0]);
tWithMDDI=tau./(2*pi*FRP)*timeDivisions;  %ms

FLG=0;
    asnBackUp = ASN; %this is for when starting for a stable condensate and shifting ASN to collapse BEC.
    ASN = asnForEquilibStart;
[x0, fval]=fsolve(@feqntrap,guessSize,optimset('Display','final'));
    ASN=asnBackUp;
%change size of BEC
xx0(1)=x0(1)*changeRadialAxial(1);
xx0(2)=x0(2)*changeRadialAxial(2);
[tau0,y0]=ode113(@feqntrapdynamic,[0 endtau], [xx0(1);0;xx0(2);0]);
tNoMDDI=tau0./(2*pi*FRP)*timeDivisions;  %ms

Asp0=y0(:,1)./y0(:,3);
Asp=y(:,1)./y(:,3);



% x(1) is qr, x(2) is qrd, x(3) is qz, x(4) is qzd

